@@ -533,7 +533,8 @@ class Reconciliation(ModelSQL, ModelView):
                             'party1': line.party.rec_name,
                             'party2': party.rec_name,
                             })
-            if not account.company.currency.is_zero(debit - credit):
+            if (account
+                    and not account.company.currency.is_zero(debit - credit)):
                 lang = Lang.get()
                 debit = lang.currency(debit, account.company.currency)
                 credit = lang.currency(credit, account.company.currency)
@@ -986,8 +987,7 @@ class Line(ModelSQL, ModelView):
 
         # Use LEFT JOIN to allow database optimization
         # if no joined table is used in the where clause.
-        return ((table.state != 'draft')
-            & table.move.in_(move
+        return (table.move.in_(move
                 .join(period, 'LEFT', condition=move.period == period.id)
                 .join(fiscalyear, 'LEFT',
                     condition=period.fiscalyear == fiscalyear.id)
@@ -1593,7 +1593,7 @@ class Reconcile(Wizard):
             party = parties.pop()
             self.show.party = party
             self.show.parties = parties
-            return party
+            return party,
 
         if getattr(self.show, 'accounts', None) is None:
             self.show.accounts = self.get_accounts()
